@@ -4,4 +4,8 @@ from .Permutation import PermutationCipher
 from .Playfair import Playfair
 from .Shift import ShiftCipher
 from .Vigenere import VigenereCipher
-from .RailFence import RailFenceCipher
\ No newline at end of file
+from .RailFence import RailFenceCipher
+from .ADFGVX import ADFGVXCipher
+from .Columnar import ColumnarTranspositionCipher
+from .OneTimePad import OneTimePad
+from .Polybius import PolybiusSquareCipher
\ No newline at end of file
